;; Generated package description from consult-flycheck.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "consult-flycheck" "1.2.0.20260628.1" "Provides the command `consult-flycheck'" '((emacs "29.1") (consult "3.5") (flycheck "35")) :commit "087454a31b51ec007365f8e92a04e69409f294d3" :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("languages" "tools" "completion") :url "https://github.com/minad/consult-flycheck")
